==> CGAL-5.1-doc_html.tar.xz: doc_html/Triangulation_3/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.1 - 3D Triangulations", "index.html", [
    [ "User Manual", "index.html", [
      [ "Representation", "index.html#Triangulation3secintro", null ],
      [ "Delaunay Triangulation", "index.html#Triangulation_3Delaunay", null ],
      [ "Regular Triangulation", "index.html#Triangulation3secclassRegulartriangulation", null ],
      [ "Software Design", "index.html#Triangulation3secdesign", [
        [ "The Geometric Traits Parameter", "index.html#Triangulation3secTraits", null ],
        [ "The Triangulation Data Structure Parameter", "index.html#Triangulation3sectds", null ],
        [ "The Location Policy Parameter", "index.html#Triangulation3seclocpol", null ],
        [ "Flexibility of the Design", "index.html#Triangulation_3FlexibilityoftheDesign", null ],
        [ "Parallel Algorithms", "index.html#Triangulation_3ParallelAlgorithms", null ]
      ] ],
      [ "Examples", "index.html#Triangulation3secexamples", [
        [ "Basic Example", "index.html#Triangulation_3BasicExample", null ],
        [ "Changing the Vertex Base", "index.html#Triangulation_3ChangingtheVertexBase", [
          [ "Adding a Color", "index.html#Triangulation3secexamplescolor", null ],
          [ "Adding Handles", "index.html#Triangulation_3AddingHandles", null ]
        ] ],
        [ "Setting Information While Inserting a Range of Points", "index.html#Triangulation_3SettingInformationWhileInserting", [
          [ "Using an Iterator Over Pairs", "index.html#Triangulation_3UsinganIteratorOverPairs", null ],
          [ "Using the Boost Zip Iterator", "index.html#Triangulation_3UsingtheBoostZipIterator", null ],
          [ "Using the Boost Transform Iterator", "index.html#Triangulation_3UsingtheBoostTransformIterator", null ]
        ] ],
        [ "Iterators and Ranges", "index.html#Triangulation3secRanges", null ],
        [ "The Simplex Class", "index.html#Triangulation3secsimplex", null ],
        [ "Fast Point Location for Delaunay Triangulations", "index.html#Triangulation3exfastlocation", null ],
        [ "Finding the Cells in Conflict with a Point in a Delaunay Triangulation", "index.html#Triangulation_3FindingtheCellsinConflict", null ],
        [ "Regular Triangulation", "index.html#Triangulation_3RegularTriangulation", [
          [ "Regular Triangulation with Defaults", "index.html#Triangulation_3RegularTriangulationDefaults", null ],
          [ "Regular Triangulation with Custom Vertex", "index.html#Triangulation_3RegularTriangulationInfo", null ]
        ] ],
        [ "Parallel Insertion in Delaunay Triangulation", "index.html#Triangulation_3ParallelDelaunay", null ],
        [ "Parallel Insertion and Removal in Regular Triangulation", "index.html#Triangulation_3ParallelRegular", null ],
        [ "Draw a 3D Triangulation", "index.html#Triangulation3Draw", null ]
      ] ],
      [ "Complexity and Performance", "index.html#Triangulation3seccomplexity", [
        [ "Running Time", "index.html#Triangulation_3RunningTime", null ],
        [ "Parallel Performance", "index.html#Triangulation_3ParallelPerformance", null ],
        [ "Memory Usage", "index.html#Triangulation_3MemoryUsage", null ],
        [ "Variability Depending on the Data Sets and the Kernel", "index.html#Triangulation_3VariabilityDependingonthe", null ]
      ] ],
      [ "Design and Implementation History", "index.html#Triangulation_3Design", null ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Triangulation_3_2adding_handles_3_8cpp-example.html",
"classCGAL_1_1Triangulation__3.html#a9d997837c2cb5ecca65658ccf6dc3010",
"index.html#Triangulation_3RegularTriangulationInfo"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-5.2-doc_html.tar.xz: doc_html/Triangulation_3/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.2 - 3D Triangulations", "index.html", [
    [ "User Manual", "index.html", [
      [ "Representation", "index.html#Triangulation3secintro", null ],
      [ "Delaunay Triangulation", "index.html#Triangulation_3Delaunay", null ],
      [ "Regular Triangulation", "index.html#Triangulation3secclassRegulartriangulation", null ],
      [ "Software Design", "index.html#Triangulation3secdesign", [
        [ "The Geometric Traits Parameter", "index.html#Triangulation3secTraits", null ],
        [ "The Triangulation Data Structure Parameter", "index.html#Triangulation3sectds", null ],
        [ "The Location Policy Parameter", "index.html#Triangulation3seclocpol", null ],
        [ "Flexibility of the Design", "index.html#Triangulation_3FlexibilityoftheDesign", null ],
        [ "Parallel Algorithms", "index.html#Triangulation_3ParallelAlgorithms", null ]
      ] ],
      [ "Examples", "index.html#Triangulation3secexamples", [
        [ "Basic Example", "index.html#Triangulation_3BasicExample", null ],
        [ "Changing the Vertex Base", "index.html#Triangulation_3ChangingtheVertexBase", [
          [ "Adding a Color", "index.html#Triangulation3secexamplescolor", null ],
          [ "Adding Handles", "index.html#Triangulation_3AddingHandles", null ]
        ] ],
        [ "Setting Information While Inserting a Range of Points", "index.html#Triangulation_3SettingInformationWhileInserting", [
          [ "Using an Iterator Over Pairs", "index.html#Triangulation_3UsinganIteratorOverPairs", null ],
          [ "Using the Boost Zip Iterator", "index.html#Triangulation_3UsingtheBoostZipIterator", null ],
          [ "Using the Boost Transform Iterator", "index.html#Triangulation_3UsingtheBoostTransformIterator", null ]
        ] ],
        [ "Iterators and Ranges", "index.html#Triangulation3secRanges", null ],
        [ "The Simplex Class", "index.html#Triangulation3secsimplex", null ],
        [ "Fast Point Location for Delaunay Triangulations", "index.html#Triangulation3exfastlocation", null ],
        [ "Traversing the Triangulation Along a Segment", "index.html#Triangulation3exsegmenttraverser", null ],
        [ "Finding the Cells in Conflict with a Point in a Delaunay Triangulation", "index.html#Triangulation_3FindingtheCellsinConflict", null ],
        [ "Regular Triangulation", "index.html#Triangulation_3RegularTriangulation", [
          [ "Regular Triangulation with Defaults", "index.html#Triangulation_3RegularTriangulationDefaults", null ],
          [ "Regular Triangulation with Custom Vertex", "index.html#Triangulation_3RegularTriangulationInfo", null ]
        ] ],
        [ "Parallel Insertion in Delaunay Triangulation", "index.html#Triangulation_3ParallelDelaunay", null ],
        [ "Parallel Insertion and Removal in Regular Triangulation", "index.html#Triangulation_3ParallelRegular", null ],
        [ "Draw a 3D Triangulation", "index.html#Triangulation3Draw", null ]
      ] ],
      [ "Complexity and Performance", "index.html#Triangulation3seccomplexity", [
        [ "Running Time", "index.html#Triangulation_3RunningTime", null ],
        [ "Parallel Performance", "index.html#Triangulation_3ParallelPerformance", null ],
        [ "Memory Usage", "index.html#Triangulation_3MemoryUsage", null ],
        [ "Variability Depending on the Data Sets and the Kernel", "index.html#Triangulation_3VariabilityDependingonthe", null ]
      ] ],
      [ "Design and Implementation History", "index.html#Triangulation_3Design", null ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Refinement Relationships", "refines.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"Triangulation_3_2adding_handles_3_8cpp-example.html",
"classCGAL_1_1Triangulation__3.html#a81373c29a596ba2f1d6d93e62d1f0d79",
"index.html#Triangulation3sectds"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
